@@ -6,12 +6,14 @@ dilation <- function(y,span)
               y = as.double(y),
               nym = as.integer(length(y)),
               sp = as.integer(span),
-              ey = double(length(y)))$ey
+              ey = double(length(y)),
+              PACKAGE = "VPdtw")$ey
     res <- rev(.C("dilation",
                   y = as.double(rev(res)),
                   nym = as.integer(length(res)),
                   sp = as.integer(span),
-                  ey = double(length(res)))$ey)
+                  ey = double(length(res)),
+                  PACKAGE = "VPdtw")$ey)
     names(res) <- nmes
     res
   }
